.. important::
   Before using these commands you need to add your database configuration in config (``.hckrcfg`` file), please refer :ref:`Configuring your databases <configuration>`


.. click:: hckr.cli.db:db
   :prog: hckr db
   :nested: full
